==> haskell-wai-logger-2.3.0-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.0
id: wai-logger-2.3.0-7zRA0Cf9IITF25xH3p21BV
key: wai-logger-2.3.0-7zRA0Cf9IITF25xH3p21BV
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
abi: 79f8580dde0c58ce6805a0fc6eb49cae
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-logger-2.3.0
hs-libraries: HSwai-logger-2.3.0-7zRA0Cf9IITF25xH3p21BV
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteorder-1.0.4-BbL4c17EpZrL9PcZm0xys9 bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
    fast-logger-2.4.7-5q6cKzCUmhpFUH581aMKto
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG unix-2.7.2.0
    unix-time-0.3.7-HcxGsrnTmTlC98pyanzoMW
    wai-3.2.1.1-3kBgN7EuSbyJsj8pT2dpLl
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.3.0-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.0
id: wai-logger-2.3.0-2u4LkdpwNN1EtFak1F5NZn
key: wai-logger-2.3.0-2u4LkdpwNN1EtFak1F5NZn
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
abi: 7f52e86e996ff823fab6b6dc2c7d3066
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-logger-2.3.0
hs-libraries: HSwai-logger-2.3.0-2u4LkdpwNN1EtFak1F5NZn
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteorder-1.0.4-BbL4c17EpZrL9PcZm0xys9 bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
    fast-logger-2.4.7-5q6cKzCUmhpFUH581aMKto
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG unix-2.7.2.0
    unix-time-0.3.7-HcxGsrnTmTlC98pyanzoMW
    wai-3.2.1.1-1tyXra1bExD5E5dzTFMy2m
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
